==> openshift-model-5.8.1-sources.jar: io/fabric8/openshift/api/model/ImageTagFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
public class ImageTagFluentImpl<A extends io.fabric8.openshift.api.model.ImageTagFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.ImageTagFluent<A>{
  public ImageTagFluentImpl() {
  }
  public ImageTagFluentImpl(io.fabric8.openshift.api.model.ImageTag instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withImage(instance.getImage()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private java.lang.String apiVersion;
  private io.fabric8.openshift.api.model.ImageBuilder image;
  private java.lang.String kind;
  private io.fabric8.kubernetes.api.model.ObjectMetaBuilder metadata;
  private io.fabric8.openshift.api.model.TagReferenceBuilder spec;
  private io.fabric8.openshift.api.model.NamedTagEventListBuilder status;
  public java.lang.String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(java.lang.String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public java.lang.Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0) {
    return (A)withApiVersion(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildImage instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.Image getImage() {
    return this.image!=null?this.image.build():null;
  }
  public io.fabric8.openshift.api.model.Image buildImage() {
    return this.image!=null?this.image.build():null;
  }
  public A withImage(io.fabric8.openshift.api.model.Image image) {
    _visitables.get("image").remove(this.image);
    if (image!=null){ this.image= new io.fabric8.openshift.api.model.ImageBuilder(image); _visitables.get("image").add(this.image);} return (A) this;
  }
  public java.lang.Boolean hasImage() {
    return this.image != null;
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.ImageNested<A> withNewImage() {
    return new io.fabric8.openshift.api.model.ImageTagFluentImpl.ImageNestedImpl();
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.ImageNested<A> withNewImageLike(io.fabric8.openshift.api.model.Image item) {
    return new io.fabric8.openshift.api.model.ImageTagFluentImpl.ImageNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.ImageNested<A> editImage() {
    return withNewImageLike(getImage());
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.ImageNested<A> editOrNewImage() {
    return withNewImageLike(getImage() != null ? getImage(): new io.fabric8.openshift.api.model.ImageBuilder().build());
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.ImageNested<A> editOrNewImageLike(io.fabric8.openshift.api.model.Image item) {
    return withNewImageLike(getImage() != null ? getImage(): item);
  }
  public java.lang.String getKind() {
    return this.kind;
  }
  public A withKind(java.lang.String kind) {
    this.kind=kind; return (A) this;
  }
  public java.lang.Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0) {
    return (A)withKind(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectMeta getMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public io.fabric8.kubernetes.api.model.ObjectMeta buildMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public A withMetadata(io.fabric8.kubernetes.api.model.ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
  }
  public java.lang.Boolean hasMetadata() {
    return this.metadata != null;
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.MetadataNested<A> withNewMetadata() {
    return new io.fabric8.openshift.api.model.ImageTagFluentImpl.MetadataNestedImpl();
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.MetadataNested<A> withNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item) {
    return new io.fabric8.openshift.api.model.ImageTagFluentImpl.MetadataNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new io.fabric8.kubernetes.api.model.ObjectMetaBuilder().build());
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.MetadataNested<A> editOrNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.TagReference getSpec() {
    return this.spec!=null?this.spec.build():null;
  }
  public io.fabric8.openshift.api.model.TagReference buildSpec() {
    return this.spec!=null?this.spec.build():null;
  }
  public A withSpec(io.fabric8.openshift.api.model.TagReference spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new io.fabric8.openshift.api.model.TagReferenceBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
  }
  public java.lang.Boolean hasSpec() {
    return this.spec != null;
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.SpecNested<A> withNewSpec() {
    return new io.fabric8.openshift.api.model.ImageTagFluentImpl.SpecNestedImpl();
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.SpecNested<A> withNewSpecLike(io.fabric8.openshift.api.model.TagReference item) {
    return new io.fabric8.openshift.api.model.ImageTagFluentImpl.SpecNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new io.fabric8.openshift.api.model.TagReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.SpecNested<A> editOrNewSpecLike(io.fabric8.openshift.api.model.TagReference item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.NamedTagEventList getStatus() {
    return this.status!=null?this.status.build():null;
  }
  public io.fabric8.openshift.api.model.NamedTagEventList buildStatus() {
    return this.status!=null?this.status.build():null;
  }
  public A withStatus(io.fabric8.openshift.api.model.NamedTagEventList status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new io.fabric8.openshift.api.model.NamedTagEventListBuilder(status); _visitables.get("status").add(this.status);} return (A) this;
  }
  public java.lang.Boolean hasStatus() {
    return this.status != null;
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.StatusNested<A> withNewStatus() {
    return new io.fabric8.openshift.api.model.ImageTagFluentImpl.StatusNestedImpl();
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.StatusNested<A> withNewStatusLike(io.fabric8.openshift.api.model.NamedTagEventList item) {
    return new io.fabric8.openshift.api.model.ImageTagFluentImpl.StatusNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new io.fabric8.openshift.api.model.NamedTagEventListBuilder().build());
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.StatusNested<A> editOrNewStatusLike(io.fabric8.openshift.api.model.NamedTagEventList item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ImageTagFluentImpl that = (ImageTagFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (image != null ? !image.equals(that.image) :that.image != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  image,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public class ImageNestedImpl<N> extends io.fabric8.openshift.api.model.ImageFluentImpl<io.fabric8.openshift.api.model.ImageTagFluent.ImageNested<N>> implements io.fabric8.openshift.api.model.ImageTagFluent.ImageNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ImageNestedImpl(io.fabric8.openshift.api.model.Image item) {
      this.builder = new io.fabric8.openshift.api.model.ImageBuilder(this, item);
    }
    ImageNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.ImageBuilder(this);
    }
    io.fabric8.openshift.api.model.ImageBuilder builder;
    public N and() {
      return (N) ImageTagFluentImpl.this.withImage(builder.build());
    }
    public N endImage() {
      return and();
    }
    
  }
  public class MetadataNestedImpl<N> extends io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl<io.fabric8.openshift.api.model.ImageTagFluent.MetadataNested<N>> implements io.fabric8.openshift.api.model.ImageTagFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MetadataNestedImpl(io.fabric8.kubernetes.api.model.ObjectMeta item) {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ObjectMetaBuilder builder;
    public N and() {
      return (N) ImageTagFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  public class SpecNestedImpl<N> extends io.fabric8.openshift.api.model.TagReferenceFluentImpl<io.fabric8.openshift.api.model.ImageTagFluent.SpecNested<N>> implements io.fabric8.openshift.api.model.ImageTagFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SpecNestedImpl(io.fabric8.openshift.api.model.TagReference item) {
      this.builder = new io.fabric8.openshift.api.model.TagReferenceBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.TagReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.TagReferenceBuilder builder;
    public N and() {
      return (N) ImageTagFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  public class StatusNestedImpl<N> extends io.fabric8.openshift.api.model.NamedTagEventListFluentImpl<io.fabric8.openshift.api.model.ImageTagFluent.StatusNested<N>> implements io.fabric8.openshift.api.model.ImageTagFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    StatusNestedImpl(io.fabric8.openshift.api.model.NamedTagEventList item) {
      this.builder = new io.fabric8.openshift.api.model.NamedTagEventListBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.NamedTagEventListBuilder(this);
    }
    io.fabric8.openshift.api.model.NamedTagEventListBuilder builder;
    public N and() {
      return (N) ImageTagFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/ImageTagFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public class ImageTagFluentImpl<A extends io.fabric8.openshift.api.model.ImageTagFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.ImageTagFluent<A>{
  public ImageTagFluentImpl() {
  }
  public ImageTagFluentImpl(io.fabric8.openshift.api.model.ImageTag instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withImage(instance.getImage()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String apiVersion;
  private io.fabric8.openshift.api.model.ImageBuilder image;
  private java.lang.String kind;
  private io.fabric8.kubernetes.api.model.ObjectMetaBuilder metadata;
  private io.fabric8.openshift.api.model.TagReferenceBuilder spec;
  private io.fabric8.openshift.api.model.NamedTagEventListBuilder status;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(java.lang.String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public java.lang.Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0) {
    return (A)withApiVersion(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildImage instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.Image getImage() {
    return this.image!=null?this.image.build():null;
  }
  public io.fabric8.openshift.api.model.Image buildImage() {
    return this.image!=null?this.image.build():null;
  }
  public A withImage(io.fabric8.openshift.api.model.Image image) {
    _visitables.get("image").remove(this.image);
    if (image!=null){ this.image= new io.fabric8.openshift.api.model.ImageBuilder(image); _visitables.get("image").add(this.image);} return (A) this;
  }
  public java.lang.Boolean hasImage() {
    return this.image != null;
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.ImageNested<A> withNewImage() {
    return new io.fabric8.openshift.api.model.ImageTagFluentImpl.ImageNestedImpl();
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.ImageNested<A> withNewImageLike(io.fabric8.openshift.api.model.Image item) {
    return new io.fabric8.openshift.api.model.ImageTagFluentImpl.ImageNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.ImageNested<A> editImage() {
    return withNewImageLike(getImage());
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.ImageNested<A> editOrNewImage() {
    return withNewImageLike(getImage() != null ? getImage(): new io.fabric8.openshift.api.model.ImageBuilder().build());
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.ImageNested<A> editOrNewImageLike(io.fabric8.openshift.api.model.Image item) {
    return withNewImageLike(getImage() != null ? getImage(): item);
  }
  public java.lang.String getKind() {
    return this.kind;
  }
  public A withKind(java.lang.String kind) {
    this.kind=kind; return (A) this;
  }
  public java.lang.Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0) {
    return (A)withKind(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectMeta getMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public io.fabric8.kubernetes.api.model.ObjectMeta buildMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public A withMetadata(io.fabric8.kubernetes.api.model.ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
  }
  public java.lang.Boolean hasMetadata() {
    return this.metadata != null;
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.MetadataNested<A> withNewMetadata() {
    return new io.fabric8.openshift.api.model.ImageTagFluentImpl.MetadataNestedImpl();
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.MetadataNested<A> withNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item) {
    return new io.fabric8.openshift.api.model.ImageTagFluentImpl.MetadataNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new io.fabric8.kubernetes.api.model.ObjectMetaBuilder().build());
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.MetadataNested<A> editOrNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.TagReference getSpec() {
    return this.spec!=null?this.spec.build():null;
  }
  public io.fabric8.openshift.api.model.TagReference buildSpec() {
    return this.spec!=null?this.spec.build():null;
  }
  public A withSpec(io.fabric8.openshift.api.model.TagReference spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new io.fabric8.openshift.api.model.TagReferenceBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
  }
  public java.lang.Boolean hasSpec() {
    return this.spec != null;
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.SpecNested<A> withNewSpec() {
    return new io.fabric8.openshift.api.model.ImageTagFluentImpl.SpecNestedImpl();
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.SpecNested<A> withNewSpecLike(io.fabric8.openshift.api.model.TagReference item) {
    return new io.fabric8.openshift.api.model.ImageTagFluentImpl.SpecNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new io.fabric8.openshift.api.model.TagReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.SpecNested<A> editOrNewSpecLike(io.fabric8.openshift.api.model.TagReference item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.NamedTagEventList getStatus() {
    return this.status!=null?this.status.build():null;
  }
  public io.fabric8.openshift.api.model.NamedTagEventList buildStatus() {
    return this.status!=null?this.status.build():null;
  }
  public A withStatus(io.fabric8.openshift.api.model.NamedTagEventList status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new io.fabric8.openshift.api.model.NamedTagEventListBuilder(status); _visitables.get("status").add(this.status);} return (A) this;
  }
  public java.lang.Boolean hasStatus() {
    return this.status != null;
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.StatusNested<A> withNewStatus() {
    return new io.fabric8.openshift.api.model.ImageTagFluentImpl.StatusNestedImpl();
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.StatusNested<A> withNewStatusLike(io.fabric8.openshift.api.model.NamedTagEventList item) {
    return new io.fabric8.openshift.api.model.ImageTagFluentImpl.StatusNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new io.fabric8.openshift.api.model.NamedTagEventListBuilder().build());
  }
  public io.fabric8.openshift.api.model.ImageTagFluent.StatusNested<A> editOrNewStatusLike(io.fabric8.openshift.api.model.NamedTagEventList item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ImageTagFluentImpl that = (ImageTagFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (image != null ? !image.equals(that.image) :that.image != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  image,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public class ImageNestedImpl<N> extends io.fabric8.openshift.api.model.ImageFluentImpl<io.fabric8.openshift.api.model.ImageTagFluent.ImageNested<N>> implements io.fabric8.openshift.api.model.ImageTagFluent.ImageNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ImageNestedImpl(io.fabric8.openshift.api.model.Image item) {
      this.builder = new io.fabric8.openshift.api.model.ImageBuilder(this, item);
    }
    ImageNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.ImageBuilder(this);
    }
    io.fabric8.openshift.api.model.ImageBuilder builder;
    public N and() {
      return (N) ImageTagFluentImpl.this.withImage(builder.build());
    }
    public N endImage() {
      return and();
    }
    
  }
  public class MetadataNestedImpl<N> extends io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl<io.fabric8.openshift.api.model.ImageTagFluent.MetadataNested<N>> implements io.fabric8.openshift.api.model.ImageTagFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MetadataNestedImpl(io.fabric8.kubernetes.api.model.ObjectMeta item) {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ObjectMetaBuilder builder;
    public N and() {
      return (N) ImageTagFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  public class SpecNestedImpl<N> extends io.fabric8.openshift.api.model.TagReferenceFluentImpl<io.fabric8.openshift.api.model.ImageTagFluent.SpecNested<N>> implements io.fabric8.openshift.api.model.ImageTagFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SpecNestedImpl(io.fabric8.openshift.api.model.TagReference item) {
      this.builder = new io.fabric8.openshift.api.model.TagReferenceBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.TagReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.TagReferenceBuilder builder;
    public N and() {
      return (N) ImageTagFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  public class StatusNestedImpl<N> extends io.fabric8.openshift.api.model.NamedTagEventListFluentImpl<io.fabric8.openshift.api.model.ImageTagFluent.StatusNested<N>> implements io.fabric8.openshift.api.model.ImageTagFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    StatusNestedImpl(io.fabric8.openshift.api.model.NamedTagEventList item) {
      this.builder = new io.fabric8.openshift.api.model.NamedTagEventListBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.NamedTagEventListBuilder(this);
    }
    io.fabric8.openshift.api.model.NamedTagEventListBuilder builder;
    public N and() {
      return (N) ImageTagFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
